@@ -16,7 +16,7 @@
 #
 #  partly based on work by Nokia Solutions and Networks Oyj
 """A parallel executor for Robot Framework test cases.
-Version 2.3.1
+Version 2.4.0
 
 Supports all Robot Framework command line options and also following
 options (these must be before normal RF options):
@@ -1201,6 +1201,7 @@ def _options_for_rebot(options, start_time_string, end_time_string):
         "listener",
         "prerunmodifier",
         "monitorcolors",
+        "randomize",
     ]:
         if key in rebot_options:
             del rebot_options[key]
@@ -1818,7 +1819,13 @@ def main(args=None):
         ordering = pabot_args.get("ordering")
         if ordering:
             suite_names = _preserve_order(suite_names, ordering)
-        suite_names = _group_by_wait(_group_by_groups(suite_names))
+        if pabot_args["processes"] > 1:
+            suite_names = _group_by_wait(_group_by_groups(suite_names))
+        else:
+            all_group = GroupItem()
+            for s in suite_names:
+                all_group.add(s)
+            suite_names = [[all_group]]
         if not suite_names or suite_names == [[]]:
             _write("No tests to execute")
             if not options.get("runemptysuite", False):
